pub struct Camera<'a> { /* private fields */ }Expand description
A camera’s projection. A node can reference a camera to apply a transform to place the camera in the scene.
Implementations
sourceimpl<'a> Camera<'a>
impl<'a> Camera<'a>
sourcepub fn projection(&self) -> Projection<'_>
pub fn projection(&self) -> Projection<'_>
Returns the camera’s projection.