pub struct Accessor {
pub buffer_view: Option<Index<View>>,
pub byte_offset: Option<USize64>,
pub count: USize64,
pub component_type: Checked<GenericComponentType>,
pub extensions: Option<Accessor>,
pub extras: Void,
pub type_: Checked<Type>,
pub min: Option<Value>,
pub max: Option<Value>,
pub name: Option<String>,
pub normalized: bool,
pub sparse: Option<Sparse>,
}Expand description
A typed view into a buffer view.
Fields
buffer_view: Option<Index<View>>The parent buffer view this accessor reads from.
This field can be omitted in sparse accessors.
byte_offset: Option<USize64>The offset relative to the start of the parent BufferView in bytes.
This field can be omitted in sparse accessors.
count: USize64The number of components within the buffer view - not to be confused with the number of bytes in the buffer view.
component_type: Checked<GenericComponentType>The data type of components in the attribute.
extensions: Option<Accessor>Extension specific data.
extras: VoidOptional application specific data.
type_: Checked<Type>Specifies if the attribute is a scalar, vector, or matrix.
min: Option<Value>Minimum value of each component in this attribute.
max: Option<Value>Maximum value of each component in this attribute.
name: Option<String>Optional user-defined name for this object.
normalized: boolSpecifies whether integer data values should be normalized.
sparse: Option<Sparse>Sparse storage of attributes that deviate from their initialization value.