pub struct Animation {
pub extensions: Option<Animation>,
pub extras: Void,
pub channels: Vec<Channel>,
pub name: Option<String>,
pub samplers: Vec<Sampler>,
}Expand description
A keyframe animation.
Fields
extensions: Option<Animation>Extension specific data.
extras: VoidOptional application specific data.
channels: Vec<Channel>An array of channels, each of which targets an animation’s sampler at a node’s property.
Different channels of the same animation must not have equal targets.
name: Option<String>Optional user-defined name for this object.
samplers: Vec<Sampler>An array of samplers that combine input and output accessors with an interpolation algorithm to define a keyframe graph (but not its target).