Function ira::tobj::load_mtl

source ·
pub fn load_mtl<P>(
    file_name: P,
) -> Result<(Vec<Material>, AHashMap<String, usize>), LoadError>
where P: AsRef<Path> + Debug,
Load the materials defined in a MTL file.

Returns a pair with a Vec holding all loaded materials and a HashMap containing a mapping of material names to indices in the Vec.