pub type Contact = TrackedContact<ContactData>;Expand description
A contact between two colliders.
Aliased Type
struct Contact {
pub local_p1: OPoint<f32, Const<3>>,
pub local_p2: OPoint<f32, Const<3>>,
pub dist: f32,
pub fid1: PackedFeatureId,
pub fid2: PackedFeatureId,
pub data: ContactData,
}Fields
local_p1: OPoint<f32, Const<3>>The contact point in the local-space of the first shape.
local_p2: OPoint<f32, Const<3>>The contact point in the local-space of the second shape.
dist: f32The distance between the two contact points.
fid1: PackedFeatureIdThe feature ID of the first shape involved in the contact.
fid2: PackedFeatureIdThe feature ID of the second shape involved in the contact.
data: ContactDataUser-data associated to this contact.